torchelie.transforms
====================

.. autoclass:: torchelie.transforms.ResizeNoCrop
   :members:

.. autoclass:: torchelie.transforms.ResizedCrop
   :members:

.. autoclass:: torchelie.transforms.AdaptPad
   :members:

.. autoclass:: torchelie.transforms.MultiBranch
   :members:

.. autoclass:: torchelie.transforms.Canny
   :members:

torchelie.transforms.differentiable
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: torchelie.transforms.differentiable
   :members:
